Biblicus Documentation
======================

Corpus management and retrieval evaluation in Python.

Contents
--------

.. toctree::
   :maxdepth: 2

   CORPUS
   EXTRACTION
   BACKENDS
   DEMOS
   USER_CONFIGURATION
   TESTING
   FEATURE_INDEX
   ROADMAP
   ARCHITECTURE
   CORPUS_DESIGN
   api
